/* src/math1/rfalib/rstd.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     RSTD */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
doublereal rstd_(real *rx, integer *n, integer *jx)
{
    /* System generated locals */
    real ret_val;

    /* Local variables */
    extern doublereal rstd0_(real *, integer *, integer *), rstd1_(real *, 
	    integer *, integer *);
    static logical lmiss;
    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);

    /* Parameter adjustments */
    --rx;

    /* Function Body */
    gllget_("LMISS", &lmiss, (ftnlen)5);
    if (lmiss) {
	ret_val = rstd1_(&rx[1], n, jx);
    } else {
	ret_val = rstd0_(&rx[1], n, jx);
    }
    return ret_val;
} /* rstd_ */

